@@ -4,7 +4,7 @@ __version__ = _importlib_metadata.version(__name__)
 
 
 from di.container import Container
-from di.dependency import Dependant, DependantProtocol
+from di.dependant import Dependant
 from di.params import Depends
 
-__all__ = ("Container", "Dependant", "DependantProtocol", "Depends")
+__all__ = ("Container", "Dependant", "Depends")
