@@ -24,12 +24,12 @@ _VARIABLE_PARAMETER_KINDS = (
 )
 
 
-_expected_attributes = ("call", "scope", "shared", "get_dependencies", "is_equivalent")
+_expected_attributes = ("call", "scope", "share", "get_dependencies")
 
 
 def _is_dependant_protocol_instance(o: object) -> bool:
     # run cheap attribute checks before running isinstance
-    # isinstace is expensive since runs reflection on methods
+    # isinstance is expensive since it runs reflection on methods
     # to check argument types, etc.
     for attr in _expected_attributes:
         if not hasattr(o, attr):
@@ -37,13 +37,13 @@ def _is_dependant_protocol_instance(o: object) -> bool:
     return isinstance(o, DependantProtocol)
 
 
-class Dependant(DependantProtocol[DependencyType]):
+class Dependant(DependantProtocol[DependencyType], object):
     @overload
     def __init__(
         self,
         call: Optional[AsyncGeneratorProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
-        shared: bool = True,
+        share: bool = True,
     ) -> None:
         ...
 
@@ -52,7 +52,7 @@ class Dependant(DependantProtocol[DependencyType]):
         self,
         call: Optional[CoroutineProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
-        shared: bool = True,
+        share: bool = True,
     ) -> None:
         ...
 
@@ -61,7 +61,7 @@ class Dependant(DependantProtocol[DependencyType]):
         self,
         call: Optional[GeneratorProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
-        shared: bool = True,
+        share: bool = True,
     ) -> None:
         ...
 
@@ -70,7 +70,7 @@ class Dependant(DependantProtocol[DependencyType]):
         self,
         call: Optional[CallableProvider[DependencyType]] = None,
         scope: Optional[Scope] = None,
-        shared: bool = True,
+        share: bool = True,
     ) -> None:
         ...
 
@@ -78,23 +78,18 @@ class Dependant(DependantProtocol[DependencyType]):
         self,
         call: Optional[DependencyProviderType[DependencyType]] = None,
         scope: Scope = None,
-        shared: bool = True,
+        share: bool = True,
     ) -> None:
         self.call = call
         self.scope = scope
         self.dependencies: Optional[
             Dict[str, DependencyParameter[DependantProtocol[Any]]]
         ] = None
-        self.shared = shared
-
-    @join_docstring_from(DependantProtocol[Any].create_sub_dependant)
-    def create_sub_dependant(
-        self, call: DependencyProvider, scope: Scope, shared: bool
-    ) -> DependantProtocol[Any]:
-        return Dependant[Any](call=call, scope=scope, shared=shared)
+        self.share = share
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}(call={self.call}, scope={self.scope})"
+        share = "" if self.share is False else ", share=False"
+        return f"{self.__class__.__name__}(call={self.call}, scope={self.scope}{share})"
 
     @join_docstring_from(DependantProtocol[Any].__hash__)
     def __hash__(self) -> int:
@@ -102,27 +97,29 @@ class Dependant(DependantProtocol[DependencyType]):
 
     @join_docstring_from(DependantProtocol[Any].__eq__)
     def __eq__(self, o: object) -> bool:
-        if type(self) != type(o):
+        if type(self) is not type(o):
             return False
         assert isinstance(o, type(self))
-        if self.shared is False or o.shared is False:
+        if self.share is False or o.share is False:
             return False
         return self.call is o.call
 
-    @join_docstring_from(DependantProtocol[Any].is_equivalent)
-    def is_equivalent(self, other: DependantProtocol[Any]) -> bool:
-        return self.call is other.call and other.scope == self.scope
-
     @join_docstring_from(DependantProtocol[Any].get_dependencies)
     def get_dependencies(
         self,
     ) -> Dict[str, DependencyParameter[DependantProtocol[Any]]]:
+        """For the Dependant implementation, this serves as a cache layer on
+        top of gather_dependencies.
+        """
         if self.dependencies is None:  # type: ignore
             self.dependencies = self.gather_dependencies()
         return self.dependencies
 
-    @join_docstring_from(DependantProtocol[Any].gather_parameters)
     def gather_parameters(self) -> Dict[str, inspect.Parameter]:
+        """Collect parameters that this dependency needs to construct itself.
+
+        Generally, this means introspecting into our own callable (self.call).
+        """
         assert self.call is not None, "Cannot gather parameters without a bound call"
         return get_parameters(self.call)
 
@@ -161,7 +158,7 @@ class Dependant(DependantProtocol[DependencyType]):
                 sub_dependant = self.create_sub_dependant(
                     call=self.infer_call_from_annotation(param),
                     scope=self.scope,
-                    shared=self.shared,
+                    share=self.share,
                 )
             else:
                 continue  # pragma: no cover
@@ -169,3 +166,24 @@ class Dependant(DependantProtocol[DependencyType]):
                 dependency=sub_dependant, parameter=param
             )
         return res
+
+    def create_sub_dependant(
+        self, call: DependencyProvider, scope: Scope, share: bool
+    ) -> DependantProtocol[Any]:
+        """Create a Dependant instance from a sub-dependency of this Dependency.
+
+        This is used in the scenario where a transient dependency is inferred from a type hint.
+        For example:
+
+        >>> class Foo:
+        >>>     ...
+        >>> def foo_factory(foo: Foo) -> Foo:
+        >>>     return foo
+        >>> def parent(foo: Dependency(foo_factory)):
+        >>>    ...
+
+        In this scenario, `Dependency(foo_factory)` will call `create_sub_dependant(Foo)`.
+
+        It is recommended to transfer `scope` and possibly `share` to sub-dependencies created in this manner.
+        """
+        return Dependant[Any](call=call, scope=scope, share=share)
