@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import dataclasses
 import functools
-from typing import Any, Callable, Dict, Generic, List, Union
+from typing import Any, Dict, Generic, List, Union
 
 from di._inspect import DependencyParameter
 from di._task import AsyncTask, SyncTask
@@ -10,7 +10,7 @@ from di.types.dependencies import DependantProtocol
 from di.types.providers import Dependency, DependencyType
 
 
-@dataclasses.dataclass(frozen=True)
+@dataclasses.dataclass
 class SolvedDependency(Generic[DependencyType]):
     """Representation of a fully solved dependency.
 
@@ -25,7 +25,6 @@ class SolvedDependency(Generic[DependencyType]):
         DependantProtocol[Any], Dict[str, DependencyParameter[DependantProtocol[Any]]]
     ]
     _tasks: List[List[Union[AsyncTask[Dependency], SyncTask[Dependency]]]]
-    _get_results: Callable[[], DependencyType]
 
     @functools.cached_property
     def flat_subdependants(self) -> List[DependantProtocol[Any]]:
